==> ivend-1.0.20.tar.gz: ivend/src/include/messages.h <==
//
//	messages.h : translation phrases
//	this file is a part of the iVend system
//	copyright 1998 bill welliver
//	hww3@riverweb.com
//

// iVend.pmod functions

#define REQUIRED	"*"
#define GROUP		"Group"
#define PRODUCTS	"Products"
#define IS_LINKED	"is linked to the following "
#define NO_PRODUCTS	"No Products in this group."
#define DELETE_UNSUCCESSFUL "Delete was unsuccessful"
#define DELETED_SUCCESSFULLY "was deleted successfully."
#define NO_OPTIONS_AVAILABLE "No Options Available"

// iVend Cart Functions

#define YOUR_CART_IS_EMPTY	"Your cart is empty."	
#define CODE		"Code"
#define PRODUCT 	"Product"
#define PRICE 		"Price"
#define QUANTITY 	"Quantity"
#define TOTAL	 	"Total"
#define UPDATE_CART	"Update Cart"
#define ADD_TO_CART 	"Add to Cart"

// category_output

#define YOU_MUST_SUPPLY_A_CATEGORY_TYPE "You must supply a category type."
#define NO_PRODUCTS_AVAILABLE "Sorry, there are no products available."
#define ERROR_QUANTITY_ZERO "Error: You must select a quantity greater than zero."

// add_item

#define ADDED_SUCCESSFULLY "added successfully."

#define UNABLE_TO_FIND_PRODUCT "Unable to find product or page" 


// checkout module

#define INVALID_EMAIL_ADDRESS "You have provided an invalid email address."
#define UNABLE_TO_CONFIRM "We were unable to move your order to confirmed status. " \
        " Please contact the administrator of this store for assistance."   
#define INVALID_CREDIT_CARD "You have provided incorrect Credit Card information."

#define ITEM " item "
#define ERROR_ADDING_ITEM "Error adding item"

#define MONETARY_UNIT "$"

// shipping module
#define MUST_SELECT_SHIPPING_TYPE "You must select a shipping type."

==> ivend-1.0.30.tar.gz: ivend/src/include/messages.h <==
//
//	messages.h : translation phrases
//	this file is a part of the iVend system
//	copyright 1998 bill welliver
//	hww3@riverweb.com
//

// iVend.pmod functions

#define REQUIRED	"*"
#define GROUP		"Group"
#define PRODUCTS	"Products"
#define IS_LINKED	"is linked to the following "
#define NO_PRODUCTS	"No Products in this group."
#define DELETE_UNSUCCESSFUL "Delete was unsuccessful"
#define DELETED_SUCCESSFULLY "was deleted successfully."
#define NO_OPTIONS_AVAILABLE "No Options Available"

// iVend Cart Functions
#define YOUR_CART_IS_EMPTY	"Your cart is empty."	
#define CODE		"Code"
#define PRODUCT 	"Product"
#define PRICE 		"Price"
#define QUANTITY 	"Quantity"
#define TOTAL	 	"Total"
#define UPDATE_CART	"Update Cart"
#define ADD_TO_CART 	"Add to Cart"
#define DELETE          "Delete"
#define CHECK_OUT       "Check out"


// category_output
#define YOU_MUST_SUPPLY_A_CATEGORY_TYPE "You must supply a category type."
#define NO_PRODUCTS_AVAILABLE "Sorry, there are no products available."
#define ERROR_QUANTITY_ZERO "Error: You must select a quantity greater than zero."

// add_item

#define ADDED_SUCCESSFULLY "has been added to your cart."

#define UNABLE_TO_FIND_PRODUCT "Unable to find product or page" 


// checkout module

#define INVALID_EMAIL_ADDRESS "You have provided an invalid email address."
#define UNABLE_TO_CONFIRM "We were unable to move your order to confirmed status. " \
        " Please contact the administrator of this store for assistance."   
#define INVALID_CREDIT_CARD "You have provided incorrect Credit Card information."

#define ITEM " item "
#define ERROR_ADDING_ITEM "Error adding item"

#define MONETARY_UNIT "$"

// shipping module
#define MUST_SELECT_SHIPPING_TYPE "You must select a shipping type."

// search tag
#define CONTAINS "contains"
#define CLICK_TO_FIND "Find..."
#define NO_MATCHES "No matches were found.";
#define SEARCH_RESULTS "Your search returned:"
#define TEXT_AND "and"
#define TEXT_OR "or"
